==> nextcloud-31.0.9-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/files_external/l10n/bg.js <==
OC.L10N.register(
    "files_external",
    {
    "Grant access" : "Разреши достъпa",
    "Error configuring OAuth2" : "Грешка при конфигурирането на OAuth2",
    "Generate keys" : "Генериране на криптографски ключове",
    "Error generating key pair" : "Грешка при генериране на криптографски ключове",
    "Forbidden to manage local mounts" : "Забрана за управление на локални монтажи",
    "Storage with ID \"%d\" not found" : "Хранилище с идентификатор \"%d\" не е намерено",
    "Invalid backend or authentication mechanism class" : "Невалиден сървър или клас на механизма за удостоверяване",
    "Invalid mount point" : "Невалиден път за монтиране на файлова система",
    "Objectstore forbidden" : "Objectstore е забранен",
    "Invalid storage backend \"%s\"" : "Невалиден сървър \"%s\" на хранилище",
    "Not permitted to use backend \"%s\"" : "Не е разрешено да се използва сървър \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "Не е разрешено да се използва механизъм за удостоверяване \"%s\"",
    "Unsatisfied backend parameters" : "Незадоволителни параметри на сървъра",
    "Unsatisfied authentication mechanism parameters" : "Незадоволителни параметри на механизма за удостоверяване",
    "Insufficient data: %s" : "Недостатъчни данни: %s",
    "%s" : "%s",
    "Access key" : "Ключ за достъп",
    "Secret key" : "Секретен ключ",
    "Builtin" : "Вграден",
    "None" : "Няма",
    "OAuth2" : "OAuth2",
    "Client ID" : "Client ID",
    "Client secret" : "Тайна на клиент",
    "OpenStack v2" : "OpenStack v2 /услуга за установяване на самоличност/",
    "Login" : "Вписване",
    "Password" : "Парола",
    "Tenant name" : "Име на клиент",
    "Identity endpoint URL" : "URL адрес на крайната точка на самоличността",
    "OpenStack v3" : "OpenStack v3",
    "Domain" : "Домейн",
    "Rackspace" : "Rackspace",
    "API key" : "API ключ",
    "Global credentials" : "Глобални идентификационни данни",
    "Log-in credentials, save in database" : "Идентификационни данни за влизане, записани в база данни",
    "Log-in credentials, save in session" : "Идентификационни данни за влизане, записани в сесия",
    "RSA public key" : "RSA публичен ключ",
    "Public key" : "Публичен ключ",
    "RSA private key" : "RSA частен ключ",
    "Private key" : "Частен ключ",
    "Kerberos default realm, defaults to \"WORKGROUP\"" : "Областта по подразбиране на Kerberos, е стойността по подразбиране за \"РАБОТНАГРУПА\"",
    "Kerberos ticket Apache mode" : "Билет Kerberos, режим Apache",
    "Kerberos ticket" : "Билет за Kerberos",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "Хост",
    "Port" : "Порт",
    "Region" : "Регион",
    "Storage Class" : "Клас на хранилище",
    "Enable SSL" : "Включи SSL",
    "Enable Path Style" : "Активира Стила на Пътя",
    "Legacy (v2) authentication" : "Удостоверяване на наследени (v2) данни ",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Външна подпапка",
    "Secure https://" : "Подсигурен https://",
    "FTP" : "FTP",
    "Host" : "Хост",
    "Secure ftps://" : "Сигурен ftps://",
    "Local" : "Локално",
    "Location" : "Местоположение",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Root",
    "SFTP with secret key login" : "SFTP с таен ключ за вход ",
    "SMB/CIFS" : "SMB/CIFS",
    "Share" : "Споделяне",
    "Show hidden files" : "Показване и на скрити файлове",
    "Verify ACL access when listing files" : "Проверка на ACL достъп при подреждане на файлове",
    "Timeout" : "Време за изчакване",
    "SMB/CIFS using OC login" : "SMB/CIFS с помощта на OC вписване",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Име на услугата",
    "Request timeout (seconds)" : "Време за изчакване на заявката (секунди)",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : " PHP подръжката на cURL не е включена или инсталирана. Монтирането на %s не е възможно. Моля да поискате системния администратор да я инсталира.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : " Поддръжката на FTP в PHP не е включена или инсталирана. Монтирането на %s не е възможно. Моля да поискате системния администратор да я инсталира.",
    "\"%1$s\" is not installed. Mounting of %2$s is not possible. Please ask your system administrator to install it." : "\"%1$s\" не е инсталиран. Прикачването на %2$sне е възможно. Моля да поискате от системния администратор да я инсталира.",
    "External storage" : "Външно хранилище",
    "External storage support" : "Поддръжка на външно хранилище",
    "Adds basic external storage support" : "Добавя основна поддръжка за външно хранилище",
    "Confirm" : "Потвърдете",
    "External mount error" : "Външна грешка при външно монтиране",
    "Storage type" : "Тип хранилище",
    "Unknown" : "Неизвестен",
    "Scope" : "Обхват",
    "Personal" : "Личен",
    "System" : "Системна информация",
    "(Group)" : "(Група)",
    "Compatibility with Mac NFD encoding (slow)" : "Съвместимост с кодиране на Mac NFD (бавно)",
    "Enable encryption" : "Включване на криптиране",
    "Enable previews" : "Активиране на визуализациите",
    "Enable sharing" : "Активиране на споделянето",
    "Check for changes" : "Проверка за промени",
    "Never" : "Никога",
    "Once every direct access" : "Веднъж на всеки директен достъп",
    "Read only" : "Само за четене",
    "Disconnect" : "Прекъсване на връзката",
    "Admin defined" : "Дефиниран от администратор",
    "Automatic status checking is disabled due to the large number of configured storages, click to check status" : "Автоматичната проверка на състоянието е деактивирана поради големия брой конфигурирани хранилища, щракнете, за проверка на състоянието",
    "Delete storage?" : "Изтриване на хранилище?",
    "Click to recheck the configuration" : "Щракнете, за повторна  проверка на конфигурацията",
    "Saved" : "Запазено",
    "Saving …" : "Записване …",
    "Save" : "Запис",
    "No external storage configured or you don't have the permission to configure them" : "Няма конфигурирано външно хранилище или нямате право да го конфигурирате",
    "Open documentation" : "Отвори документацията",
    "Folder name" : "Име на папката",
    "Authentication" : "Удостоверяване",
    "Configuration" : "Настройки",
    "Available for" : "Достъпно за",
    "Add storage" : "Добави хранилище",
    "Advanced settings" : "Допълнителни настройки",
    "Global credentials can be used to authenticate with multiple external storages that have the same credentials." : "Глобалните идентификационни данни могат да се използват за удостоверяване с множество външни хранилища, които имат едни и същи идентификационни данни.",
    "Error configuring OAuth1" : "Грешка при конфигурирането на OAuth1",
    "Please provide a valid app key and secret." : "Моля да предоставете валиден ключ и тайна на приложението.",
    "OAuth1" : "OAuth1",
    "App key" : " Ключ на приложение",
    "App secret" : "Тайна на приложение",
    "Are you sure you want to disconnect this external storage? It will make the storage unavailable in Nextcloud and will lead to a deletion of these files and folders on any sync client that is currently connected but will not delete any files and folders on the external storage itself." : "Наистина ли искате да изключите това външно хранилище? Това ще направи хранилището недостъпно в Nextcloud и ще доведе до изтриване на тези файлове и папки на всеки синхронизиран клиент, който е свързан в момента, но няма да изтрие никакви файлове и папки от самото външно хранилище."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-32.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/files_external/l10n/bg.js <==
OC.L10N.register(
    "files_external",
    {
    "Grant access" : "Разреши достъпa",
    "Error configuring OAuth2" : "Грешка при конфигурирането на OAuth2",
    "Generate keys" : "Генериране на криптографски ключове",
    "Error generating key pair" : "Грешка при генериране на криптографски ключове",
    "Forbidden to manage local mounts" : "Забрана за управление на локални монтажи",
    "Storage with ID \"%d\" not found" : "Хранилище с идентификатор \"%d\" не е намерено",
    "Invalid backend or authentication mechanism class" : "Невалиден сървър или клас на механизма за удостоверяване",
    "Invalid mount point" : "Невалиден път за монтиране на файлова система",
    "Objectstore forbidden" : "Objectstore е забранен",
    "Invalid storage backend \"%s\"" : "Невалиден сървър \"%s\" на хранилище",
    "Not permitted to use backend \"%s\"" : "Не е разрешено да се използва сървър \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "Не е разрешено да се използва механизъм за удостоверяване \"%s\"",
    "Unsatisfied backend parameters" : "Незадоволителни параметри на сървъра",
    "Unsatisfied authentication mechanism parameters" : "Незадоволителни параметри на механизма за удостоверяване",
    "Insufficient data: %s" : "Недостатъчни данни: %s",
    "%s" : "%s",
    "Access key" : "Ключ за достъп",
    "Secret key" : "Секретен ключ",
    "Builtin" : "Вграден",
    "None" : "Няма",
    "OAuth2" : "OAuth2",
    "Client ID" : "Client ID",
    "Client secret" : "Тайна на клиент",
    "OpenStack v2" : "OpenStack v2 /услуга за установяване на самоличност/",
    "Login" : "Вписване",
    "Password" : "Парола",
    "Tenant name" : "Име на клиент",
    "Identity endpoint URL" : "URL адрес на крайната точка на самоличността",
    "OpenStack v3" : "OpenStack v3",
    "Domain" : "Домейн",
    "Rackspace" : "Rackspace",
    "API key" : "API ключ",
    "Global credentials" : "Глобални идентификационни данни",
    "Log-in credentials, save in database" : "Идентификационни данни за влизане, записани в база данни",
    "Log-in credentials, save in session" : "Идентификационни данни за влизане, записани в сесия",
    "RSA public key" : "RSA публичен ключ",
    "Public key" : "Публичен ключ",
    "RSA private key" : "RSA частен ключ",
    "Private key" : "Частен ключ",
    "Kerberos default realm, defaults to \"WORKGROUP\"" : "Областта по подразбиране на Kerberos, е стойността по подразбиране за \"РАБОТНАГРУПА\"",
    "Kerberos ticket Apache mode" : "Билет Kerberos, режим Apache",
    "Kerberos ticket" : "Билет за Kerberos",
    "Bucket" : "Bucket",
    "Hostname" : "Хост",
    "Port" : "Порт",
    "Region" : "Регион",
    "Storage Class" : "Клас на хранилище",
    "Enable SSL" : "Включи SSL",
    "Enable Path Style" : "Активира Стила на Пътя",
    "Legacy (v2) authentication" : "Удостоверяване на наследени (v2) данни ",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Външна подпапка",
    "Secure https://" : "Подсигурен https://",
    "FTP" : "FTP",
    "Host" : "Хост",
    "Secure ftps://" : "Сигурен ftps://",
    "Local" : "Локално",
    "Location" : "Местоположение",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Root",
    "SFTP with secret key login" : "SFTP с таен ключ за вход ",
    "SMB/CIFS" : "SMB/CIFS",
    "Share" : "Споделяне",
    "Show hidden files" : "Показване и на скрити файлове",
    "Verify ACL access when listing files" : "Проверка на ACL достъп при подреждане на файлове",
    "Timeout" : "Време за изчакване",
    "SMB/CIFS using OC login" : "SMB/CIFS с помощта на OC вписване",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Име на услугата",
    "Request timeout (seconds)" : "Време за изчакване на заявката (секунди)",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : " PHP подръжката на cURL не е включена или инсталирана. Монтирането на %s не е възможно. Моля да поискате системния администратор да я инсталира.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : " Поддръжката на FTP в PHP не е включена или инсталирана. Монтирането на %s не е възможно. Моля да поискате системния администратор да я инсталира.",
    "\"%1$s\" is not installed. Mounting of %2$s is not possible. Please ask your system administrator to install it." : "\"%1$s\" не е инсталиран. Прикачването на %2$sне е възможно. Моля да поискате от системния администратор да я инсталира.",
    "External storage" : "Външно хранилище",
    "External storage support" : "Поддръжка на външно хранилище",
    "Adds basic external storage support" : "Добавя основна поддръжка за външно хранилище",
    "Confirm" : "Потвърдете",
    "Open in Files" : "Отворете във Файлове",
    "External mount error" : "Външна грешка при външно монтиране",
    "Storage type" : "Тип хранилище",
    "Unknown" : "Неизвестен",
    "Scope" : "Обхват",
    "Personal" : "Личен",
    "System" : "Системна информация",
    "(Group)" : "(Група)",
    "Compatibility with Mac NFD encoding (slow)" : "Съвместимост с кодиране на Mac NFD (бавно)",
    "Enable encryption" : "Включване на криптиране",
    "Enable previews" : "Активиране на визуализациите",
    "Enable sharing" : "Активиране на споделянето",
    "Check for changes" : "Проверка за промени",
    "Never" : "Никога",
    "Once every direct access" : "Веднъж на всеки директен достъп",
    "Read only" : "Само за четене",
    "Disconnect" : "Прекъсване на връзката",
    "Admin defined" : "Дефиниран от администратор",
    "Automatic status checking is disabled due to the large number of configured storages, click to check status" : "Автоматичната проверка на състоянието е деактивирана поради големия брой конфигурирани хранилища, щракнете, за проверка на състоянието",
    "Delete storage?" : "Изтриване на хранилище?",
    "Click to recheck the configuration" : "Щракнете, за повторна  проверка на конфигурацията",
    "Saved" : "Запазено",
    "Saving …" : "Запазване ...",
    "Save" : "Запис",
    "No external storage configured or you don't have the permission to configure them" : "Няма конфигурирано външно хранилище или нямате право да го конфигурирате",
    "Open documentation" : "Отвори документацията",
    "Folder name" : "Име на папката",
    "Authentication" : "Удостоверяване",
    "Configuration" : "Настройки",
    "Available for" : "Достъпно за",
    "Add storage" : "Добави хранилище",
    "Advanced settings" : "Допълнителни настройки",
    "Global credentials can be used to authenticate with multiple external storages that have the same credentials." : "Глобалните идентификационни данни могат да се използват за удостоверяване с множество външни хранилища, които имат едни и същи идентификационни данни.",
    "Error configuring OAuth1" : "Грешка при конфигурирането на OAuth1",
    "Please provide a valid app key and secret." : "Моля да предоставете валиден ключ и тайна на приложението.",
    "OAuth1" : "OAuth1",
    "App key" : " Ключ на приложение",
    "App secret" : "Тайна на приложение",
    "Are you sure you want to disconnect this external storage? It will make the storage unavailable in Nextcloud and will lead to a deletion of these files and folders on any sync client that is currently connected but will not delete any files and folders on the external storage itself." : "Наистина ли искате да изключите това външно хранилище? Това ще направи хранилището недостъпно в Nextcloud и ще доведе до изтриване на тези файлове и папки на всеки синхронизиран клиент, който е свързан в момента, но няма да изтрие никакви файлове и папки от самото външно хранилище.",
    "Saving …" : "Записване …"
},
"nplurals=2; plural=(n != 1);");
